@@ -130,7 +130,7 @@ void defaultlook::fliptohorizontal()
 
     // figure out moving the systray, if it exists
 
-    // figure out systrayID, and tasklistID
+    // figure out systrayID, pusleaudio plugin, and tasklistID
 
     QString systrayID = runCmd("grep \\\"systray\\\" ~/.config/xfce4/xfconf/xfce-perchannel-xml/xfce4-panel.xml").output;
     systrayID=systrayID.remove("\"").section("-",1,1).section(" ",0,0);
@@ -140,6 +140,10 @@ void defaultlook::fliptohorizontal()
     tasklistID=tasklistID.remove("\"").section("-",1,1).section(" ",0,0);
     qDebug() << "tasklist: " << tasklistID;
 
+    QString pulseaudioID = runCmd("grep pulseaudio ~/.config/xfce4/xfconf/xfce-perchannel-xml/xfce4-panel.xml").output;
+    pulseaudioID=pulseaudioID.remove("\"").section("-",1,1).section(" ",0,0);
+    qDebug() << "pulseaudio: " << pulseaudioID;
+
     // if systray exists, do a bunch of stuff to relocate it a list of plugins.  If not present, do nothing to list
 
     if (systrayID !=""){
@@ -184,7 +188,7 @@ void defaultlook::fliptohorizontal()
 
             //try to move to in front of clock if present
 
-            QString clockID = runCmd("grep clock ~/.config/xfce4/xfconf/xfce-perchannel-xml/xfce4-panel.xml").output;
+            QString clockID = runCmd("grep -m1 \"clock\\|datetime\" ~/.config/xfce4/xfconf/xfce-perchannel-xml/xfce4-panel.xml").output;
             QString switchID;
             clockID=clockID.remove("\"").section("-",1,1).section(" ",0,0);
             qDebug() << "clockID: " << clockID;
@@ -215,7 +219,20 @@ void defaultlook::fliptohorizontal()
             pluginIDs.insert(switchIDindex, systrayID);
             qDebug() << "reordered list" << pluginIDs;
         }
+
+        //if pulsaudio plugin is present, move it to in front of systray
+        if (pulseaudioID != "") {
+            int switchIDindex;
+            pluginIDs.removeAll(pulseaudioID);
+            switchIDindex = pluginIDs.indexOf(systrayID) + 1;
+            pluginIDs.insert(switchIDindex, pulseaudioID);
+            qDebug() << "reorderd PA list" << pluginIDs;
+
+
+        }
     }
+
+
     //now reverse the list
 
     std::reverse(pluginIDs.begin(), pluginIDs.end());
@@ -269,6 +286,10 @@ void defaultlook::fliptovertical()
     tasklistID=tasklistID.remove("\"").section("-",1,1).section(" ",0,0);
     qDebug() << "tasklist: " << tasklistID;
 
+    QString pulseaudioID = runCmd("grep pulseaudio ~/.config/xfce4/xfconf/xfce-perchannel-xml/xfce4-panel.xml").output;
+    pulseaudioID=pulseaudioID.remove("\"").section("-",1,1).section(" ",0,0);
+    qDebug() << "pulseaudio: " << pulseaudioID;
+
     //if systray exists, do a bunch of stuff to try to move it in a logical way
 
     if (systrayID !=""){
@@ -353,6 +374,17 @@ void defaultlook::fliptovertical()
         pluginIDs.insert(switchindex, systrayID);
         qDebug() << "reordered list" << pluginIDs;
 
+
+        //if pulsaudio plugin is present, move it to in front of systray
+        if (pulseaudioID != "") {
+            int switchIDindex;
+            pluginIDs.removeAll(pulseaudioID);
+            switchIDindex = pluginIDs.indexOf(systrayID) + 1;
+            pluginIDs.insert(switchIDindex, pulseaudioID);
+            qDebug() << "reorderd PA list" << pluginIDs;
+
+
+        }
         //move the expanding separator
 
         if (testexpandsep == "true") {
@@ -377,7 +409,7 @@ void defaultlook::fliptovertical()
         QString value = changeIterator.next();
         cmdstring = QString(cmdstring + "-s " + value + " ");
         qDebug() << cmdstring;
-    }
+    }QString switchID;
 
     //flip the panel plugins and pray for a miracle
 
@@ -814,7 +846,7 @@ void defaultlook::setupEtc()
     }
 
     //setup no-ellipse option
-    QFileInfo fileinfo2(home_path + "/.local/share/mx-tweak-data/no-ellipse-desktop-filenames.rc");
+    QFileInfo fileinfo2(home_path + "/.config/gtk-3.0/no-ellipse-desktop-filenames.css");
     if (fileinfo2.exists()) {
         ui->checkboxNoEllipse->setChecked(true);
     } else {
@@ -1198,27 +1230,25 @@ void defaultlook::on_buttonThemeApply_clicked()
 
     //set whisker themeing
     QString home_path = QDir::homePath();
-    QFileInfo whisker_check(home_path + "/.gtkrc-2.0");
+    QFileInfo whisker_check(home_path + "/.config/gtk-3.0/gtk.css");
     if (whisker_check.exists()) {
-        qDebug() << "existing gtkrc-2.0 found";
-        //fix problem with original tweak setup
-        runCmd("sed -i '/[[:space:]].local\\/share\\/mx-tweak-data\\/whisker-tweak.rc/d' " + whisker_check.absoluteFilePath());
-        QString cmd = "cat " + home_path + "/.gtkrc-2.0 |grep -q whisker-tweak.rc";
+        qDebug() << "existing gtk.css found";
+        QString cmd = "cat " + home_path + "/.config/gtk-3.0/gtk.css |grep -q whisker-tweak.css";
         if (system(cmd.toUtf8()) == 0 ) {
             qDebug() << "include statement found";
         } else {
             qDebug() << "adding include statement";
-            QString cmd = "echo 'include \".local/share/mx-tweak-data/whisker-tweak.rc\"' >> " + home_path + "/.gtkrc-2.0";
+            QString cmd = "echo '@import url(\"whisker-tweak.css\");' >> " + home_path + "/.config/gtk-3.0/gtk.css";
             system(cmd.toUtf8());
         }
     }else {
-        qDebug() << "creating simple gtkrc-2.0 file";
-        QString cmd = "echo 'include \".local/share/mx-tweak-data/whisker-tweak.rc\"' >> " + home_path + "/.gtkrc-2.0";
+        qDebug() << "creating simple gtk.css file";
+        QString cmd = "echo '@import url(\"whisker-tweak.css\");' >> " + home_path + "/.config/gtk-3.0/gtk.css";
         system(cmd.toUtf8());
     }
 
    //add whisker info
-    runCmd("awk '/<begin_gtk_whisker_theme_code>/{flag=1;next}/<end_gtk_whisker_theme_code>/{flag=0}flag' \"" +fileinfo.absoluteFilePath() +"\" > " + home_path + "/.local/share/mx-tweak-data/whisker-tweak.rc");
+    runCmd("awk '/<begin_gtk_whisker_theme_code>/{flag=1;next}/<end_gtk_whisker_theme_code>/{flag=0}flag' \"" +fileinfo.absoluteFilePath() +"\" > " + home_path + "/.config/gtk-3.0/whisker-tweak.css");
 
     //restart xfce4-panel
 
@@ -1316,32 +1346,33 @@ void defaultlook::on_ButtonApplyEtc_clicked()
     QString home_path = QDir::homePath();
     if (ui->checkboxNoEllipse->isChecked()) {
         //set desktop themeing
-        QFileInfo gtk_check(home_path + "/.gtkrc-2.0");
+        QFileInfo gtk_check(home_path + "/.config/gtk-3.0/gtk.css");
         if (gtk_check.exists()) {
-            qDebug() << "existing gtkrc-2.0 found";
-            QString cmd = "cat " + home_path + "/.gtkrc-2.0 |grep -q no-ellipse-desktop-filenames.rc";
+            qDebug() << "existing gtk.css found";
+            QString cmd = "cat " + home_path + "/.config/gtk-3.0/gtk.css |grep -q no-ellipse-desktop-filenames.css";
             if (system(cmd.toUtf8()) == 0 ) {
                 qDebug() << "include statement found";
             } else {
                 qDebug() << "adding include statement";
-                QString cmd = "echo 'include \".local/share/mx-tweak-data/no-ellipse-desktop-filenames.rc\"' >> " + home_path + "/.gtkrc-2.0";
+                QString cmd = "echo '@import url(\"no-ellipse-desktop-filenames.css\");' >> " + home_path + "/.config/gtk-3.0/gtk.css";
                 system(cmd.toUtf8());
             }
         }else {
-            qDebug() << "creating simple gtkrc-2.0 file";
-            QString cmd = "echo 'include \".local/share/mx-tweak-data/no-ellipse-desktop-filenames.rc\"' >> " + home_path + "/.gtkrc-2.0";
+            qDebug() << "creating simple gtk.css file";
+            QString cmd = "echo '@import url(\"no-ellipse-desktop-filenames.css\");' >> " + home_path + "/.config/gtk-3.0/gtk.css";
             system(cmd.toUtf8());
         }
         //add modification config
-        runCmd("cp /usr/share/mx-tweak/no-ellipse-desktop-filenames.rc " + home_path + "/.local/share/mx-tweak-data/no-ellipse-desktop-filenames.rc ");
+        runCmd("cp /usr/share/mx-tweak/no-ellipse-desktop-filenames.css " + home_path + "/.config/gtk-3.0/no-ellipse-desktop-filenames.css ");
 
         //restart xfdesktop by with xfdesktop --quite && xfdesktop &
 
         system("xfdesktop --quit && sleep .5 && xfdesktop &");
     }else {
-        QFileInfo noellipse_check(home_path + "/.local/share/mx-tweak-data/no-ellipse-desktop-filenames.rc");
+        QFileInfo noellipse_check(home_path + "/.config/gtk-3.0/no-ellipse-desktop-filenames.css");
         if (noellipse_check.exists()) {
-            runCmd("rm -f " + home_path + "/.local/share/mx-tweak-data/no-ellipse-desktop-filenames.rc");
+            runCmd("rm -f " + home_path + "/.config/gtk-3.0/no-ellipse-desktop-filenames.css");
+            runCmd("sed -i '/no-ellipse-desktop-filenames.css/d' " + home_path + "/.config/gtk-3.0/gtk.css");
             system("xfdesktop --quit && sleep .5 && xfdesktop &");
         }
     }
@@ -1476,12 +1507,11 @@ void defaultlook::savethemeundo()
     }
 
     //backup whiskermenu changes
-    // if whisker-tweak.rc exists, back it up
-    QFileInfo fileinfo(home_path + "/.local/share/mx-tweak-data/whisker-tweak.rc");
+    // if whisker-tweak.css exists, back it up
+    QFileInfo fileinfo(home_path + "/.config/gtk-3.0/whisker-tweak.css");
     if (fileinfo.exists()) {
-        runCmd("cp " + home_path + "/.local/share/mx-tweak-data/whisker-tweak.rc /tmp/whisker-tweak.rc.undo." + whiskeriterator);
-        //runCmd("echo cp " + home_path + "/.local/share/mx-tweak-data/whisker-tweak.rc.undo " + fileinfo.absoluteFilePath() + " >> undo.txt");
-        undocommand = undocommand + "cp /tmp/whisker-tweak.rc.undo." + whiskeriterator + " " + fileinfo.absoluteFilePath();
+        runCmd("cp " + home_path + "/.config/gtk-3.0/whisker-tweak.css /tmp/whisker-tweak.css.undo." + whiskeriterator);
+        undocommand = undocommand + "cp /tmp/whisker-tweak.css.undo." + whiskeriterator + " " + fileinfo.absoluteFilePath();
     } else {
         // delete the file
         //runCmd("echo rm -f " + fileinfo.absoluteFilePath() + " >> undo.txt" );
